#
# spec file for package python-pyOCD
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyOCD
Version:        0.22.0
Release:        3.3
Summary:        CMSIS-DAP debugger for python
License:        Apache-2.0
URL:            https://github.com/mbedmicro/pyOCD
Source:         https://files.pythonhosted.org/packages/source/p/pyocd/pyocd-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-usb
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-pyocd = %{version}
Obsoletes:      python-pyocd < %{version}
BuildArch:      noarch
%python_subpackages

%description
On-chip debugger and flasher tool for ARM microcontrollers.

%prep
%setup -q -n pyocd-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pyocd
%python_clone -a %{buildroot}%{_bindir}/pyocd-flashtool
%python_clone -a %{buildroot}%{_bindir}/pyocd-gdbserver
%python_clone -a %{buildroot}%{_bindir}/pyocd-tool
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative pyocd
%python_install_alternative pyocd-flashtool
%python_install_alternative pyocd-gdbserver
%python_install_alternative pyocd-tool

%postun
%python_uninstall_alternative pyocd
%python_uninstall_alternative pyocd-flashtool
%python_uninstall_alternative pyocd-gdbserver
%python_uninstall_alternative pyocd-tool

%files %{python_files}
%python_alternative %{_bindir}/pyocd
%python_alternative %{_bindir}/pyocd-flashtool
%python_alternative %{_bindir}/pyocd-gdbserver
%python_alternative %{_bindir}/pyocd-tool
%{python_sitelib}/pyocd
%{python_sitelib}/pyocd-%{version}.dist-info

%changelog
* Thu Jul 27 2023 Steve Kowalik <steven.kowalik@suse.com>
- Switch to setuptools_scm, rather than setuptools_scm_git_archive.
- Switch to pyproject macros.
- Stop using greedy globs in %%files.
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.22.0:
  * Fixed regression with Cypress PSoC6 targets (#680) and merged in cumulative PSoC6 updates from Cypress.
  * Resolved a number of issues (but not all) with NXP LPC55S69.
  * Update ST NUCLEO-H743ZI.
  * Correct the wrong part number for MIMXRT1064-EVK board.
  * Correct part number for ST NUCLEO-WB55RG board.
  * Fix location of input data for flash algorithms in STM32F412xx target.
  * Address an issue with the built-in target STM32L031x6 by disabling double buffered flash programming.
* Tue Jul 23 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.21.0:
  * Too many changes to enumerate
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Apr  1 2018 afaerber@suse.de
- Convert to singlespec
- Update to v0.8.1a1
* Wed Jan  7 2015 afaerber@suse.de
- Drop py2pack-generated conditional on suse_version (matejcik)
* Tue Jan  6 2015 afaerber@suse.de
- Add runtime dependency on pyUSB
* Tue Jan  6 2015 afaerber@suse.de
- Initial: v0.2
